import { Button } from "@/components/ui/button";
import { Moon, Sun } from "lucide-react";
import * as React from "react";

export function ModeToggle() {
	const [theme, setTheme] = React.useState<"theme-light" | "dark" | "system">(
		"theme-light",
	);

	React.useEffect(() => {
		const isDarkMode = document.documentElement.classList.contains("dark");
		setTheme(isDarkMode ? "dark" : "theme-light");
	}, []);

	React.useEffect(() => {
		const isDark = theme === "dark";

		document.documentElement.classList.add("disable-transitions");
		document.documentElement.classList[isDark ? "add" : "remove"]("dark");

		window
			.getComputedStyle(document.documentElement)
			.getPropertyValue("opacity");

		requestAnimationFrame(() => {
			document.documentElement.classList.remove("disable-transitions");
		});
	}, [theme]);

	const toggleTheme = () => {
		setTheme(theme === "dark" ? "theme-light" : "dark");
	};

	return (
		<Button
			variant="outline"
			size="icon"
			className="relative overflow-hidden"
			onClick={toggleTheme}
			title="Toggle theme"
		>
			<Sun className="size-4 absolute inset-0 m-auto scale-100 rotate-0 transition-all duration-500 dark:scale-0 dark:-rotate-90" />
			<Moon className="size-4 absolute inset-0 m-auto scale-0 rotate-90 transition-all duration-500 dark:scale-100 dark:rotate-0" />
			<span className="sr-only">Toggle theme</span>
		</Button>
	);
}
